package com.ruoyi.system.service.columns.impl;

import java.util.List;

import com.ruoyi.system.domain.columns.YjSense;
import com.ruoyi.system.mapper.colums.YjSenseMapper;
import com.ruoyi.system.service.columns.IYjSenseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 瑜伽常识Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
@Service
public class YjSenseServiceImpl implements IYjSenseService
{
    @Autowired
    private YjSenseMapper yjSenseMapper;

    /**
     * 查询瑜伽常识
     * 
     * @param id 瑜伽常识主键
     * @return 瑜伽常识
     */
    @Override
    public YjSense selectYjSenseById(String id)
    {
        return yjSenseMapper.selectYjSenseById(id);
    }

    /**
     * 查询瑜伽常识列表
     * 
     * @param yjSense 瑜伽常识
     * @return 瑜伽常识
     */
    @Override
    public List<YjSense> selectYjSenseList(YjSense yjSense)
    {
        return yjSenseMapper.selectYjSenseList(yjSense);
    }

    /**
     * 新增瑜伽常识
     * 
     * @param yjSense 瑜伽常识
     * @return 结果
     */
    @Override
    public int insertYjSense(YjSense yjSense)
    {
        return yjSenseMapper.insertYjSense(yjSense);
    }

    /**
     * 修改瑜伽常识
     * 
     * @param yjSense 瑜伽常识
     * @return 结果
     */
    @Override
    public int updateYjSense(YjSense yjSense)
    {
        return yjSenseMapper.updateYjSense(yjSense);
    }

    /**
     * 批量删除瑜伽常识
     * 
     * @param ids 需要删除的瑜伽常识主键
     * @return 结果
     */
    @Override
    public int deleteYjSenseByIds(String[] ids)
    {
        return yjSenseMapper.deleteYjSenseByIds(ids);
    }

    /**
     * 删除瑜伽常识信息
     * 
     * @param id 瑜伽常识主键
     * @return 结果
     */
    @Override
    public int deleteYjSenseById(String id)
    {
        return yjSenseMapper.deleteYjSenseById(id);
    }
}
